@@ -1,8 +1,10 @@
 Configuration = {
     "dev": False,
+    "whatap_code_start": False,
     "ignore_whatap_stdout" : False,
     "net_udp_port": "6600",
     "web_static_content_extensions": "js, htm, html, gif, png, jpg, css, swf, ico",
+
     "trace_auto_normalize_enabled": True,
     "trace_user_enabled": True,
     "trace_user_using_ip": True,
@@ -14,6 +16,8 @@ Configuration = {
     "trace_ignore_url_prefix": None,
     "trace_websocket_enabled": False,
 
+    "trace_llm_log_enabled": False,
+
     "debug": False,
     "query_string_enabled": False,
     "query_string_urls": "",
@@ -50,6 +54,10 @@ Configuration = {
 	"stat_error_max_count": 1000,
 	"stat_useragent_max_count": 500,
 
+    "standalone_enabled" : False,
+    "standalone_type" : "single-transaction",
+    "standalone_transaction_patterns" : "",
+
     "user_header_ticket_enabled": False,
     "user_header_ticket":"",
     "trace_user_cookie_limit":2048,
