@@ -5,6 +5,7 @@ from whatap.conf.configure import Configure as conf
 from whatap.trace.trace_context_manager import TraceContextManager
 from whatap.util.date_util import DateUtil
 from whatap.util.hexa32 import Hexa32
+from whatap.util.hash_util import HashUtil
 
 from whatap.util.linked_map import LinkedMap
 from resource import getrusage, RUSAGE_SELF
@@ -166,6 +167,8 @@ class TraceContext(object):
     def transferPOID(self):
         if not self.transfer_poid:
             self.transfer_poid = ",".join(
-                (Hexa32.toString32(conf.PCODE), Hexa32.toString32(conf.OKIND), Hexa32.toString32(int(conf.OID))))
+                (Hexa32.toString32(conf.PCODE),
+                 Hexa32.toString32(HashUtil.hashFromString(conf.OKIND) if isinstance(conf.OKIND, str) else conf.OKIND),
+                 Hexa32.toString32(int(conf.OID))))
 
         return self.transfer_poid
