@@ -7,50 +7,60 @@ DEFINITION = {
     'plugin': [
         ('', 'instrument_plugin'),
     ],
-    'httpc_httplib': [
+    'standalone': [
+        ('', 'instrument_standalone_single'),
+        ('', 'instrument_standalone_multiple')
+    ],
+    'httpc.httplib': [
         ('httplib', 'instrument_httplib'),
         ('http.client', 'instrument_httplib'),
         ('httplib2', 'instrument_httplib2'),
     ],
-    'httpc_requests': [
+    'httpc.requests': [
         ('requests.sessions', 'instrument_requests'),
     ],
-    'httpc_urllib3': [
+    'httpc.urllib3': [
         ('urllib3.request', 'instrument_urllib3'),
     ],
-    'httpc_django': [
+    'httpc.django': [
         ('revproxy.views', 'instrument_revproxy_views'),
     ],
-    'database_mysql': [
+    'httpc.httpx' : [
+        ('httpx', 'instrument_httpx')
+    ],
+    'database.mysql': [
         ('MySQLdb', 'instrument_MySQLdb'),
         ('MySQLdb.cursors', 'instrument_MySQLdb_cursors'),
         ('pymysql', 'instrument_pymysql'),
         ('pymysql.cursors', 'instrument_pymysql_cursors'),
     ],
-    'database_postgresql': [
+    'database.postgresql': [
         ('psycopg2', 'instrument_psycopg2'),
         ('psycopg2._psycopg', 'instrument_psycopg2_connection'),
         ('psycopg2.extensions', 'instrument_psycopg2_extensions'),
     ],
-    'database_toolkit': [
+    'database.neo4j': [
+        ('neo4j', 'instrument_neo4j')
+    ],
+    'database.toolkit': [
         ('sqlalchemy.orm.session', 'instrument_sqlalchemy'),
         ('sqlalchemy.engine.default', 'instrument_sqlalchemy_engine'),
         ('sqlalchemy.engine.create', 'instrument_sqlalchemy_engine_basic'),
         ('sqlalchemy.engine', 'instrument_sqlalchemy_engine_basic'),
     ],
-    'application_starlette' : [
+    'application.starlette' : [
         ('starlette.websockets' , 'instrument_starlette_websocket'),
     ],
-    'application_wsgi': [
+    'application.wsgi': [
         ('', ''),
     ],
-    'application_bottle': [
+    'application.bottle': [
         ('bottle', 'instrument'),
     ],
-    'application_cherrypy': [
+    'application.cherrypy': [
         ('cherrypy', 'instrument'),
     ],
-    'application_django': [
+    'application.django': [
         ('django.core.handlers.wsgi', 'instrument'),
         ('django.core.handlers.base', 'instrument_handlers_base'),
         ('django.views.generic.base', 'instrument_generic_base'),
@@ -64,60 +74,63 @@ DEFINITION = {
          False),
 
     ],
-    'application_django_asgi': [
+    'application.django_asgi': [
         ('django.core.handlers.asgi', 'instrument_asgi'),
     ],
-    'application_flask': [
+    'application.flask': [
         ('flask', 'instrument'),
     ],
-    'application_tornado': [
+    'application.tornado': [
         ('tornado.web', 'instrument'),
     ],
-    'application_celery': [
+    'application.celery': [
         ('celery.execute.trace', 'instrument_celery_execute_trace'),
         ('celery.task.trace', 'instrument_celery_execute_trace'),
         ('celery.app.trace', 'instrument_celery_execute_trace'),
     ],
-    'database_redis':[
+    'database.redis':[
         ('redis','instrument_redis_connection'),
     ],
-    'email_smtp':[
+    'email.smtp':[
         ('smtplib','instrument_smtp'),
     ],
-    'amqp_pika':[
+    'amqp.pika':[
         ('pika.channel','instrument_pika'),
     ],
-    'application_nameko': [
+    'application.nameko': [
         ('nameko.containers', 'instrument_nameko_spawn_worker'),
         ('spsengine.containers', 'instrument_nameko_spawn_worker'),
     ],
-    'application_graphql':[
+    'application.graphql':[
         #graphen-core 3.x~
         ('graphql.execution.execute','instrument_graphql'),
 
         #graphen-core 2.x
         ('graphql.execution.executor','instrument_graphql'),
     ],
-    'database_mongo':[
+    'database.mongo':[
         ('pymongo','instrument_mongo_client'),
     ],
     'logging':[
         ('logging.handlers', 'instrument_logging'),
         ('loguru._handler','instrument_loguru'),
     ],
-    'application_fastapi': [
+    'application.fastapi': [
         ('fastapi.applications', 'instrument_applications'),
         ('fastapi.routing', 'instrument'),
         ('fastapi.dependencies.utils', 'instrument_util'),
 
     ],
-    'application_frappe': [
+    'application.frappe': [
         ('frappe.app', 'instrument'),
     ],
-    'application_odoo': [
+    'application.odoo': [
         ('odoo', 'instrument'),
     ],
-    'database_cxoracle':[
+    'database.cxoracle':[
         ('cx_Oracle', 'instrument_oracle_client'),
     ],
+    'llm.openai':[
+        ('openai' , 'instrument_openai')
+    ]
 }
